@@ -22,6 +22,7 @@ from deployment.libs.gitarchive import GitArchiver
 from deployment.common import *
 from deployment.plugin import Plugin
 from deployment.plugins.info import WriteCommitInfo, NotifyMail
+from deployment.plugins.supervisor import Supervisor
 
 
 class SrcClone(Plugin):
@@ -59,6 +60,9 @@ class SrcClone(Plugin):
             config['source']['local'] = os.getcwd()
         config['source']['local'] = os.path.expanduser(config['source']['local'])
 
+        if not os.path.isdir(config['source']['local']):
+            raise NotConfiguredError("config['source']['local'] directory does not exists")
+
     def run(self, *args, **kwargs):
         self.validate_config()
 
@@ -76,7 +80,7 @@ class SrcClone(Plugin):
         repo = config['source']['git']['repo']
 
         env.host_string = 'localhost'
-        pretty_print('[+] Repository clone start: %s' % local_directory, 'info')
+        pretty_print('[+] Repository check start: %s' % local_directory, 'info')
 
         # if not len(directory):
         #     pretty_print('Directory not selected, assuming current one.', 'info')
@@ -94,8 +98,9 @@ class SrcClone(Plugin):
         old_dir = os.getcwd()
         os.chdir(local_directory)
 
+        pretty_print("Checking if repository exists %s" % os.path.join(local_directory, repo_directory), "info")
         try:
-            if not os.path.isdir("%s/.git" % repo_directory):  # repo = Repo(dir)
+            if not os.path.isdir(os.path.join(repo_directory, ".git")):  # repo = Repo(dir)
                 if os.path.isdir(repo_directory):
                     raise IOError('Directory already exists and is not repository. Clone will fail. Please check your '
                                   'configuration')
@@ -103,7 +108,7 @@ class SrcClone(Plugin):
 
             repo = Repo(repo_directory)
 
-            pretty_print('Repository found. Branch: %s' % repo.active_branch, 'info')
+            pretty_print('Repository found.', 'info')
 
         except InvalidGitRepositoryError:  # Repo doesn't exists
             pretty_print('Repository not found. Creating new one, using %s.' % repo, 'info')
@@ -117,7 +122,7 @@ class SrcClone(Plugin):
 
         if repo.active_branch is not branch:
             pretty_print('Changing branch', 'info')
-            repo.git.checkout('master')
+            repo.git.checkout(branch)
 
         pretty_print('Pulling changes', 'info')
         repo.git.pull('origin', branch)
@@ -201,7 +206,11 @@ class SrcPrepare(Plugin):
         old_dir2 = os.getcwd()
         os.chdir(repo_directory)
 
-        extra = [os.path.join(changelog_file), ]
+        if len(changelog_file):
+            extra = [os.path.join(changelog_file), ]
+        else:
+            extra = []
+
         archiver = GitArchiver(main_repo_abspath=os.getcwd(), include_dirs=dirs, extra=extra)
         archiver.create(os.path.join(old_dir2, archive_file))
 
@@ -871,7 +880,6 @@ class Deploy(Plugin):
             pretty_print("Remote clean flag not set, using True", 'info')
             config['remote']['clean'] = True
 
-
     def run(self, *args, **kwargs):
         self.validate_config()
 
@@ -900,6 +908,11 @@ class Deploy(Plugin):
 
         SrcRemoteVenv(config).run(check=False)
 
+        try:
+            Supervisor(config).run()
+        except NotConfiguredError:
+            pretty_print('Supervisor not configured, ommiting', 'info')
+
         pretty_print('Local cleaning flag: %s' % config['source']['clean'])
         if config['source']['clean']:
             clean = SrcLocalClean(config)
